pub struct AddPartyArguments {
pub party_id: String,
pub synchronizer_id: String,
pub source_participant_uid: String,
pub topology_serial: u32,
pub participant_permission: i32,
}Fields
party_id: StringThe identifier of the party to be replicated.
Required
synchronizer_id: StringThe identifier of the synchronizer where the party will be replicated.
Required
source_participant_uid: StringThe unique identifier of a source participant already hosting the party.
Required
topology_serial: u32TODO(#31414): Remove: Either by inferring it internally or require record time (validFrom of the effective topology transaction) TODO(#31414): Ensure that it will work with offboarding and re-onboarding The serial number of the PartyToParticipant topology transaction. Maps the party to this target participant.
Required
participant_permission: i32TODO(#31414): Remove: Figure it out from the topology transaction The permission level of the party on the target participant.
Required
Implementations
Sourceimpl AddPartyArguments
impl AddPartyArguments
Sourcepub fn participant_permission(&self) -> ParticipantPermission
pub fn participant_permission(&self) -> ParticipantPermission
Returns the enum value of participant_permission, or the default if the field is set to an invalid enum value.
Sourcepub fn set_participant_permission(&mut self, value: ParticipantPermission)
pub fn set_participant_permission(&mut self, value: ParticipantPermission)
Sets participant_permission to the provided enum value.