pub struct CommandStatus {
pub started: Option<Timestamp>,
pub completed: Option<Timestamp>,
pub completion: Option<Completion>,
pub state: i32,
pub commands: Vec<Command>,
pub request_statistics: Option<RequestStatistics>,
pub updates: Option<CommandUpdates>,
pub synchronizer_id: String,
pub timings: Vec<Timing>,
}Fields
started: Option<Timestamp>Time at which the command was received for interpretation by the participant.
Required
completed: Option<Timestamp>Time at which the command was completed.
Optional
completion: Option<Completion>The completion associated with the command Contains only default values if the command is still pending
Optional
state: i32The state of the command
Required
commands: Vec<Command>The individual submitted commands
Required: must be non-empty
request_statistics: Option<RequestStatistics>Statistics about the command request
Optional
updates: Option<CommandUpdates>The ledger updates effected by the command
Optional
synchronizer_id: StringSynchronizer-ID. May be optional if the transaction was not yet routed.
Optional
timings: Vec<Timing>Timings for the individual stages
Optional: can be empty
Implementations
Sourceimpl CommandStatus
impl CommandStatus
Sourcepub fn state(&self) -> CommandState
pub fn state(&self) -> CommandState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: CommandState)
pub fn set_state(&mut self, value: CommandState)
Sets state to the provided enum value.