pub struct GenerateExternalPartyTopologyRequest {
pub synchronizer: String,
pub party_hint: String,
pub public_key: Option<SigningPublicKey>,
pub local_participant_observation_only: bool,
pub other_confirming_participant_uids: Vec<String>,
pub confirmation_threshold: u32,
pub observing_participant_uids: Vec<String>,
}Fields
synchronizer: StringSynchronizer-id for which we are building this request. TODO(#27670) support synchronizer aliases
Required
party_hint: StringThe actual party id will be constructed from this hint and a fingerprint of the public key
Required
public_key: Option<SigningPublicKey>Public key
Required
local_participant_observation_only: boolIf true, then the local participant will only be observing, not confirming. Default false.
Optional
other_confirming_participant_uids: Vec<String>Other participant ids which should be confirming for this party
Optional: can be empty
confirmation_threshold: u32Confirmation threshold >= 1 for the party. Defaults to all available confirmers (or if set to 0).
Optional
observing_participant_uids: Vec<String>Other observing participant ids for this party
Optional: can be empty