pub struct GetCommandStatusRequest {
pub command_id_prefix: String,
pub state: i32,
pub limit: u32,
}Fields
command_id_prefix: StringFilter by command id
Optional
state: i32Filter by state
Optional
limit: u32Limit the number of returned statuses Defaults to 100 if not set
Optional
Implementations
Sourceimpl GetCommandStatusRequest
impl GetCommandStatusRequest
Sourcepub fn state(&self) -> CommandState
pub fn state(&self) -> CommandState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: CommandState)
pub fn set_state(&mut self, value: CommandState)
Sets state to the provided enum value.