pub struct GetPartiesRequest {
pub parties: Vec<String>,
pub identity_provider_id: String,
}Expand description
Required authorization: HasRight(ParticipantAdmin) OR IsAuthenticatedIdentityProviderAdmin(identity_provider_id)
Fields
parties: Vec<String>The stable, unique identifier of the Daml parties.
Must be valid PartyIdStrings (as described in value.proto).
Required: must be non-empty
identity_provider_id: StringThe id of the Identity Provider whose parties should be retrieved.
If not set, assume the party is managed by the default identity provider or party is not hosted by the participant.
Optional