pub struct GetPartiesResponse {
pub party_details: Vec<PartyDetails>,
}Fields
party_details: Vec<PartyDetails>The details of the requested Daml parties by the participant, if known. The party details may not be in the same order as requested.
Required: must be non-empty