pub struct GetUserRequest {
pub user_id: String,
pub identity_provider_id: String,
}Expand description
Required authorization: HasRight(ParticipantAdmin) OR IsAuthenticatedIdentityProviderAdmin(identity_provider_id) OR IsAuthenticatedUser(user_id)
Fields
user_id: StringThe user whose data to retrieve. If set to empty string (the default), then the data for the authenticated user will be retrieved.
Optional
identity_provider_id: StringThe id of the Identity Provider
If not set, assume the user is managed by the default identity provider.
Optional