pub struct ListUserRightsRequest {
pub user_id: String,
pub identity_provider_id: String,
}Expand description
Required authorization: HasRight(ParticipantAdmin) OR IsAuthenticatedIdentityProviderAdmin(identity_provider_id) OR IsAuthenticatedUser(user_id)
Fields
user_id: StringThe user for which to list the rights. If set to empty string (the default), then the rights for the authenticated user will be listed.
Required
identity_provider_id: StringThe id of the Identity Provider
If not set, assume the user is managed by the default identity provider.
Optional