ListUsersRequest

Struct ListUsersRequest 

pub struct ListUsersRequest {
    pub page_token: String,
    pub page_size: i32,
    pub identity_provider_id: String,
}
Required authorization: HasRight(ParticipantAdmin) OR IsAuthenticatedIdentityProviderAdmin(identity_provider_id)

Fields

page_token: String

Pagination token to determine the specific page to fetch. Leave empty to fetch the first page.

Optional

page_size: i32

Maximum number of results to be returned by the server. The server will return no more than that many results, but it might return fewer. If 0, the server will decide the number of results to be returned.

Optional

identity_provider_id: String

The id of the Identity Provider If not set, assume the user is managed by the default identity provider.

Optional