pub struct PartyReplicationStatus {
pub parameters: Option<ReplicationParameters>,
pub authorization: Option<PartyReplicationAuthorization>,
pub replication: Option<AcsReplicationProgress>,
pub indexing: Option<AcsIndexingProgress>,
pub has_completed: bool,
pub error_message: Option<PartyReplicationError>,
}Expand description
Describes the various lifecycle states of a party replication operation.
Fields
parameters: Option<ReplicationParameters>Static party replication parameters.
Required
Topology authorization details; set once the party is authorized on the target participant.
Optional
replication: Option<AcsReplicationProgress>ACS replication progress; set once the data transfer begins.
Optional
indexing: Option<AcsIndexingProgress>Indexing progress metrics; set once background ledger indexing begins.
Optional
has_completed: boolIndicates whether the party replication operation has completed successfully.
Required
error_message: Option<PartyReplicationError>Diagnostic details; populated during transient or terminal failures.
Optional