pub struct PruneRequest {
pub prune_up_to: i64,
pub submission_id: String,
pub prune_all_divulged_contracts: bool,
}Fields
prune_up_to: i64Inclusive valid absolute offset (positive integer) up to which the ledger is to be pruned. By default the following data is pruned:
- All normal and divulged contracts that have been archived before
prune_up_to. - All transaction events and completions before
prune_up_to - All immediately divulged contracts created before
prune_up_toindependent of whether they were archived beforeprune_up_to.
Required
submission_id: StringUnique submission identifier. If not populated, defaults to a random identifier, used for logging.
Optional
prune_all_divulged_contracts: boolDeprecated flag used to prune all immediately and retroactively divulged contracts. It is a no-op since the divulged contracts are pruned along with the deactivated contracts.
Optional