pub struct RevokeUserRightsRequest {
pub user_id: String,
pub rights: Vec<Right>,
pub identity_provider_id: String,
}Expand description
Remove the rights from the set of rights granted to the user.
Required authorization: HasRight(ParticipantAdmin) OR IsAuthenticatedIdentityProviderAdmin(identity_provider_id)
Fields
user_id: StringThe user from whom to revoke rights.
Required
rights: Vec<Right>The rights to revoke.
Optional: can be empty
identity_provider_id: StringThe id of the Identity Provider
If not set, assume the user is managed by the default identity provider.
Optional