pub struct UpdateIdentityProviderConfigRequest {
pub identity_provider_config: Option<IdentityProviderConfig>,
pub update_mask: Option<FieldMask>,
}Fields
identity_provider_config: Option<IdentityProviderConfig>The identity provider config to update. Modifiable
Required
update_mask: Option<FieldMask>An update mask specifies how and which properties of the IdentityProviderConfig message are to be updated.
An update mask consists of a set of update paths.
A valid update path points to a field or a subfield relative to the IdentityProviderConfig message.
A valid update mask must:
- contain at least one update path,
- contain only valid update paths.
Fields that can be updated are marked as Modifiable.
For additional information see the documentation for standard protobuf3’s google.protobuf.FieldMask.
Required