pub struct UpdateUserIdentityProviderIdRequest {
pub user_id: String,
pub source_identity_provider_id: String,
pub target_identity_provider_id: String,
}Expand description
Required authorization: HasRight(ParticipantAdmin)
Fields
user_id: StringUser to update
Required
source_identity_provider_id: StringCurrent identity provider ID of the user If omitted, the default IDP is assumed
Optional
target_identity_provider_id: StringTarget identity provider ID of the user If omitted, the default IDP is assumed
Optional