pub struct UpdateUserRequest {
pub user: Option<User>,
pub update_mask: Option<FieldMask>,
}Expand description
Required authorization: HasRight(ParticipantAdmin) OR IsAuthenticatedIdentityProviderAdmin(user.identity_provider_id)
Fields
user: Option<User>The user to update. Modifiable
Required
update_mask: Option<FieldMask>An update mask specifies how and which properties of the User message are to be updated.
An update mask consists of a set of update paths.
A valid update path points to a field or a subfield relative to the User message.
A valid update mask must:
- contain at least one update path,
- contain only valid update paths.
Fields that can be updated are marked as Modifiable.
An update path can also point to a non-Modifiable fields such as ‘id’ and ‘metadata.resource_version’
because they are used:
- to identify the user resource subject to the update,
- for concurrent change control.
Examples of valid update paths: ‘primary_party’, ‘metadata’, ‘metadata.annotations’.
For additional information see the documentation for standard protobuf3’s google.protobuf.FieldMask.
For similar Ledger API see com.daml.ledger.api.v2.admin.UpdatePartyDetailsRequest.
Required