pub struct UploadDarFileRequest {
pub dar_file: Vec<u8>,
pub submission_id: String,
pub vetting_change: i32,
pub synchronizer_id: String,
}Fields
dar_file: Vec<u8>Contains a Daml archive DAR file, which in turn is a jar like zipped
container for daml_lf archives. See further details in
daml_lf.proto.
Required: must be non-empty
submission_id: StringUnique submission identifier. If not populated, a random identifier will be generated.
Optional
vetting_change: i32How to vet packages in the DAR being uploaded
Optional
synchronizer_id: StringOnly used if VettingChange is set to VETTING_CHANGE_VET_ALL_PACKAGES, in order to specify which synchronizer to vet on.
If synchronizer_id is set, the synchronizer with this ID will be used. If synchronizer_id is unset and the participant is only connected to a single synchronizer, that synchronizer will be used by default. If synchronizer_id is unset and the participant is connected to multiple synchronizers, the request will error out with PACKAGE_SERVICE_CANNOT_AUTODETECT_SYNCHRONIZER.
Optional
Implementations
Sourceimpl UploadDarFileRequest
impl UploadDarFileRequest
Sourcepub fn vetting_change(&self) -> VettingChange
pub fn vetting_change(&self) -> VettingChange
Returns the enum value of vetting_change, or the default if the field is set to an invalid enum value.
Sourcepub fn set_vetting_change(&mut self, value: VettingChange)
pub fn set_vetting_change(&mut self, value: VettingChange)
Sets vetting_change to the provided enum value.