pub struct ValidateDarFileRequest {
pub dar_file: Vec<u8>,
pub submission_id: String,
pub synchronizer_id: String,
}Expand description
Performs the same checks that UploadDarFileRequest would perform, but doesn’t upload the DAR.
Fields
dar_file: Vec<u8>Contains a Daml archive DAR file, which in turn is a jar like zipped
container for daml_lf archives. See further details in
daml_lf.proto.
Required: must be non-empty
submission_id: StringUnique submission identifier. If not defined, defaults to a random identifier.
Optional
synchronizer_id: StringIf synchronizer_id is set, the synchronizer with this ID will be used. If synchronizer_id is unset and the participant is only connected to a single synchronizer, that synchronizer will be used by default. If synchronizer_id is unset and the participant is connected to multiple synchronizers, the request will error out with PACKAGE_SERVICE_CANNOT_AUTODETECT_SYNCHRONIZER.
Optional