UserManagementServiceClient

Struct UserManagementServiceClient 

pub struct UserManagementServiceClient<T> { /* private fields */ }
Service to manage users and their rights for interacting with the Ledger API served by a participant node.

The authorization rules for its RPCs are specified on the <RpcName>Request messages as boolean expressions over these facts:

  1. HasRight(r) denoting whether the authenticated user has right r and
  2. IsAuthenticatedUser(uid) denoting whether uid is the empty string or equal to the id of the authenticated user.
  3. IsAuthenticatedIdentityProviderAdmin(idp) denoting whether idp is equal to the identity_provider_id of the authenticated user and the user has an IdentityProviderAdmin right.

If user_id is set to the empty string (the default), then the data for the authenticated user will be retrieved. If identity_provider_id is set to an empty string, then it’s effectively set to the value of access token’s ‘iss’ field if that is provided. If identity_provider_id remains an empty string, the default identity provider will be assumed.

The fields of request messages (and sub-messages) are marked either as Optional or Required:

  1. Optional denoting the client may leave the field unset when sending a request.
  2. Required denoting the client must set the field to a non-default value when sending a request.

A user resource consists of:

  1. a set of properties represented by the User message,
  2. a set of user rights, where each right is represented by the Right message.

A user resource, once it has been created, can be modified. In order to update the properties represented by the User message use the UpdateUser RPC. The only fields that can be modified are those marked as Modifiable. In order to grant or revoke user rights use GrantRights' and RevokeRights`` RPCs.

Implementations

Source

impl UserManagementServiceClient<Channel>

pub async fn connect<D>( dst: D, ) -> Result<UserManagementServiceClient<Channel>, Error>
where D: TryInto<Endpoint>, <D as TryInto<Endpoint>>::Error: Into<Box<dyn Error + Sync + Send>>,

Attempt to create a new client by connecting to a given endpoint.

Source

impl<T> UserManagementServiceClient<T>
where T: GrpcService<Body>, <T as GrpcService<Body>>::Error: Into<Box<dyn Error + Sync + Send>>, <T as GrpcService<Body>>::ResponseBody: Body<Data = Bytes> + Send + 'static, <<T as GrpcService<Body>>::ResponseBody as Body>::Error: Into<Box<dyn Error + Sync + Send>> + Send,

pub fn new(inner: T) -> UserManagementServiceClient<T>

pub fn with_origin(inner: T, origin: Uri) -> UserManagementServiceClient<T>

pub fn with_interceptor<F>( inner: T, interceptor: F, ) -> UserManagementServiceClient<InterceptedService<T, F>>

pub fn send_compressed( self, encoding: CompressionEncoding, ) -> UserManagementServiceClient<T>

Compress requests with the given encoding.

This requires the server to support it otherwise it might respond with an error.

pub fn accept_compressed( self, encoding: CompressionEncoding, ) -> UserManagementServiceClient<T>

Enable decompressing responses.

pub fn max_decoding_message_size( self, limit: usize, ) -> UserManagementServiceClient<T>

Limits the maximum size of a decoded message.

Default: 4MB

pub fn max_encoding_message_size( self, limit: usize, ) -> UserManagementServiceClient<T>

Limits the maximum size of an encoded message.

Default: usize::MAX

pub async fn create_user( &mut self, request: impl IntoRequest<CreateUserRequest>, ) -> Result<Response<CreateUserResponse>, Status>

Create a new user.

pub async fn get_user( &mut self, request: impl IntoRequest<GetUserRequest>, ) -> Result<Response<GetUserResponse>, Status>

Get the user data of a specific user or the authenticated user.

pub async fn update_user( &mut self, request: impl IntoRequest<UpdateUserRequest>, ) -> Result<Response<UpdateUserResponse>, Status>

Update selected modifiable attribute of a user resource described by the User message.

pub async fn delete_user( &mut self, request: impl IntoRequest<DeleteUserRequest>, ) -> Result<Response<DeleteUserResponse>, Status>

Delete an existing user and all its rights.

pub async fn list_users( &mut self, request: impl IntoRequest<ListUsersRequest>, ) -> Result<Response<ListUsersResponse>, Status>

List all existing users.

pub async fn grant_user_rights( &mut self, request: impl IntoRequest<GrantUserRightsRequest>, ) -> Result<Response<GrantUserRightsResponse>, Status>

Grant rights to a user. Granting rights does not affect the resource version of the corresponding user.

pub async fn revoke_user_rights( &mut self, request: impl IntoRequest<RevokeUserRightsRequest>, ) -> Result<Response<RevokeUserRightsResponse>, Status>

Revoke rights from a user. Revoking rights does not affect the resource version of the corresponding user.

pub async fn list_user_rights( &mut self, request: impl IntoRequest<ListUserRightsRequest>, ) -> Result<Response<ListUserRightsResponse>, Status>

List the set of all rights granted to a user.

pub async fn update_user_identity_provider_id( &mut self, request: impl IntoRequest<UpdateUserIdentityProviderIdRequest>, ) -> Result<Response<UpdateUserIdentityProviderIdResponse>, Status>

Update the assignment of a user from one IDP to another.