CommandServiceClient

Struct CommandServiceClient 

pub struct CommandServiceClient<T> { /* private fields */ }
Command Service is able to correlate submitted commands with completion data, identify timeouts, and return contextual information with each tracking result. This supports the implementation of stateless clients.

Note that submitted commands generally produce completion events as well, even in case a command gets rejected. For example, the participant SHOULD produce a completion event for a rejection of a duplicate command.

Implementations

Source

impl CommandServiceClient<Channel>

pub async fn connect<D>(dst: D) -> Result<CommandServiceClient<Channel>, Error>
where D: TryInto<Endpoint>, <D as TryInto<Endpoint>>::Error: Into<Box<dyn Error + Sync + Send>>,

Attempt to create a new client by connecting to a given endpoint.

Source

impl<T> CommandServiceClient<T>
where T: GrpcService<Body>, <T as GrpcService<Body>>::Error: Into<Box<dyn Error + Sync + Send>>, <T as GrpcService<Body>>::ResponseBody: Body<Data = Bytes> + Send + 'static, <<T as GrpcService<Body>>::ResponseBody as Body>::Error: Into<Box<dyn Error + Sync + Send>> + Send,

pub fn new(inner: T) -> CommandServiceClient<T>

pub fn with_origin(inner: T, origin: Uri) -> CommandServiceClient<T>

pub fn with_interceptor<F>( inner: T, interceptor: F, ) -> CommandServiceClient<InterceptedService<T, F>>

pub fn send_compressed( self, encoding: CompressionEncoding, ) -> CommandServiceClient<T>

Compress requests with the given encoding.

This requires the server to support it otherwise it might respond with an error.

pub fn accept_compressed( self, encoding: CompressionEncoding, ) -> CommandServiceClient<T>

Enable decompressing responses.

pub fn max_decoding_message_size(self, limit: usize) -> CommandServiceClient<T>

Limits the maximum size of a decoded message.

Default: 4MB

pub fn max_encoding_message_size(self, limit: usize) -> CommandServiceClient<T>

Limits the maximum size of an encoded message.

Default: usize::MAX

pub async fn submit_and_wait( &mut self, request: impl IntoRequest<SubmitAndWaitRequest>, ) -> Result<Response<SubmitAndWaitResponse>, Status>

Submits a single composite command and waits for its result. Propagates the gRPC error of failed submissions including Daml interpretation errors.

pub async fn submit_and_wait_for_transaction( &mut self, request: impl IntoRequest<SubmitAndWaitForTransactionRequest>, ) -> Result<Response<SubmitAndWaitForTransactionResponse>, Status>

Submits a single composite command, waits for its result, and returns the transaction. Propagates the gRPC error of failed submissions including Daml interpretation errors.

pub async fn submit_and_wait_for_reassignment( &mut self, request: impl IntoRequest<SubmitAndWaitForReassignmentRequest>, ) -> Result<Response<SubmitAndWaitForReassignmentResponse>, Status>

Submits a single composite reassignment command, waits for its result, and returns the reassignment. Propagates the gRPC error of failed submission.