pub struct ContractServiceClient<T> { /* private fields */ }Expand description
This service is experimental / alpha, therefore no backwards compatibility is guaranteed.
Implementations
Sourceimpl<T> ContractServiceClient<T>where
T: GrpcService<Body>,
<T as GrpcService<Body>>::Error: Into<Box<dyn Error + Sync + Send>>,
<T as GrpcService<Body>>::ResponseBody: Body<Data = Bytes> + Send + 'static,
<<T as GrpcService<Body>>::ResponseBody as Body>::Error: Into<Box<dyn Error + Sync + Send>> + Send,
impl<T> ContractServiceClient<T>where
T: GrpcService<Body>,
<T as GrpcService<Body>>::Error: Into<Box<dyn Error + Sync + Send>>,
<T as GrpcService<Body>>::ResponseBody: Body<Data = Bytes> + Send + 'static,
<<T as GrpcService<Body>>::ResponseBody as Body>::Error: Into<Box<dyn Error + Sync + Send>> + Send,
pub fn new(inner: T) -> ContractServiceClient<T>
pub fn with_origin(inner: T, origin: Uri) -> ContractServiceClient<T>
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> ContractServiceClient<InterceptedService<T, F>>where
F: Interceptor,
<T as GrpcService<Body>>::ResponseBody: Default,
T: Service<Request<Body>, Response = Response<<T as GrpcService<Body>>::ResponseBody>>,
<T as Service<Request<Body>>>::Error: Into<Box<dyn Error + Sync + Send>> + Send + Sync,
Sourcepub fn send_compressed(
self,
encoding: CompressionEncoding,
) -> ContractServiceClient<T>
pub fn send_compressed( self, encoding: CompressionEncoding, ) -> ContractServiceClient<T>
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_compressed(
self,
encoding: CompressionEncoding,
) -> ContractServiceClient<T>
pub fn accept_compressed( self, encoding: CompressionEncoding, ) -> ContractServiceClient<T>
Enable decompressing responses.
Sourcepub fn max_decoding_message_size(self, limit: usize) -> ContractServiceClient<T>
pub fn max_decoding_message_size(self, limit: usize) -> ContractServiceClient<T>
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(self, limit: usize) -> ContractServiceClient<T>
pub fn max_encoding_message_size(self, limit: usize) -> ContractServiceClient<T>
Limits the maximum size of an encoded message.
Default: usize::MAX
Sourcepub async fn get_contract(
&mut self,
request: impl IntoRequest<GetContractRequest>,
) -> Result<Response<GetContractResponse>, Status>
pub async fn get_contract( &mut self, request: impl IntoRequest<GetContractRequest>, ) -> Result<Response<GetContractResponse>, Status>
Looking up contract data by contract ID. This endpoint is experimental / alpha, therefore no backwards compatibility is guaranteed. This endpoint must not be used to look up contracts which entered the participant via party replication or repair service. If there is no contract exist with the contract ID, or there is no intersection with the querying_parties, an CONTRACT_PAYLOAD_NOT_FOUND error will be raised.