#[repr(i32)]pub enum CryptoKeyFormat {
Unspecified = 0,
Der = 1,
Raw = 2,
DerX509SubjectPublicKeyInfo = 3,
}Expand description
Serialization format for crypto keys and signatures
Variants
Unspecified = 0
Der = 1
ASN.1 + DER encoding Legacy format no longer used, except for migrations
Raw = 2
Raw encoding of a key
DerX509SubjectPublicKeyInfo = 3
ASN.1 + DER-encoding of X.509 SubjectPublicKeyInfo structure: https://datatracker.ietf.org/doc/html/rfc5280#section-4.1
Implementations
Sourceimpl CryptoKeyFormat
impl CryptoKeyFormat
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<CryptoKeyFormat>
pub fn from_str_name(value: &str) -> Option<CryptoKeyFormat>
Creates an enum from field names used in the ProtoBuf definition.