#[repr(i32)]pub enum HashFunction {
Sha256 = 0,
}Variants
Sha256 = 0
Implementations
Sourceimpl HashFunction
impl HashFunction
Sourceimpl HashFunction
impl HashFunction
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<HashFunction>
pub fn from_str_name(value: &str) -> Option<HashFunction>
Creates an enum from field names used in the ProtoBuf definition.