#[repr(i32)]pub enum PackageStatus {
Unspecified = 0,
Registered = 1,
}Variants
Unspecified = 0
The server is not aware of such a package.
Registered = 1
The server is able to execute Daml commands operating on this package.
Implementations
Sourceimpl PackageStatus
impl PackageStatus
Sourceimpl PackageStatus
impl PackageStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<PackageStatus>
pub fn from_str_name(value: &str) -> Option<PackageStatus>
Creates an enum from field names used in the ProtoBuf definition.