#[repr(i32)]pub enum SignatureFormat {
Unspecified = 0,
Raw = 1,
Der = 2,
Concat = 3,
Symbolic = 10_000,
}Variants
Unspecified = 0
Raw = 1
Signature scheme specific signature format Legacy format no longer used, except for migrations
Der = 2
ASN.1 + DER-encoding of the r and s integers, as defined in https://datatracker.ietf.org/doc/html/rfc3279#section-2.2.3
Used for ECDSA signatures
Concat = 3
Concatenation of the integers r || s in little-endian form, as defined in https://datatracker.ietf.org/doc/html/rfc8032#section-3.3
Note that this is different from the format defined in IEEE P1363, which uses concatenation in big-endian form.
Used for EdDSA signatures
Symbolic = 10_000
Symbolic crypto, must only be used for testing
Implementations
Sourceimpl SignatureFormat
impl SignatureFormat
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<SignatureFormat>
pub fn from_str_name(value: &str) -> Option<SignatureFormat>
Creates an enum from field names used in the ProtoBuf definition.