#[repr(i32)]pub enum SigningAlgorithmSpec {
Unspecified = 0,
Ed25519 = 1,
EcDsaSha256 = 2,
EcDsaSha384 = 3,
MlDsa65 = 4,
}Variants
Unspecified = 0
Ed25519 = 1
EdDSA Signature based on Curve25519 with SHA-512 http://ed25519.cr.yp.to/
EcDsaSha256 = 2
Elliptic Curve Digital Signature Algorithm with SHA256
EcDsaSha384 = 3
Elliptic Curve Digital Signature Algorithm with SHA384
MlDsa65 = 4
Implementations
Sourceimpl SigningAlgorithmSpec
impl SigningAlgorithmSpec
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of SigningAlgorithmSpec.
Sourcepub fn from_i32(value: i32) -> Option<SigningAlgorithmSpec>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<SigningAlgorithmSpec>
Use the TryFrom<i32> implementation instead
Converts an i32 to a SigningAlgorithmSpec, or None if value is not a valid variant.
Sourceimpl SigningAlgorithmSpec
impl SigningAlgorithmSpec
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<SigningAlgorithmSpec>
pub fn from_str_name(value: &str) -> Option<SigningAlgorithmSpec>
Creates an enum from field names used in the ProtoBuf definition.