#[repr(i32)]pub enum SigningKeySpec {
Unspecified = 0,
EcCurve25519 = 1,
EcP256 = 2,
EcP384 = 3,
EcSecp256k1 = 4,
MlDsa65 = 5,
}Variants
Unspecified = 0
EcCurve25519 = 1
Elliptic Curve Key from Curve25519 as defined in http://ed25519.cr.yp.to/
EcP256 = 2
Elliptic Curve Key from the NIST P-256 curve (aka secp256r1) as defined in https://doi.org/10.6028/NIST.FIPS.186-4
EcP384 = 3
Elliptic Curve Key from the NIST P-384 curve (aka secp384r1) as defined in https://doi.org/10.6028/NIST.FIPS.186-4
EcSecp256k1 = 4
Elliptic Curve Key from SECG P256k1 curve (aka secp256k1) commonly used in bitcoin and ethereum as defined in https://www.secg.org/sec2-v2.pdf
MlDsa65 = 5
Implementations
Sourceimpl SigningKeySpec
impl SigningKeySpec
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<SigningKeySpec>
pub fn from_str_name(value: &str) -> Option<SigningKeySpec>
Creates an enum from field names used in the ProtoBuf definition.