#[repr(i32)]pub enum TransactionShape {
Unspecified = 0,
AcsDelta = 1,
LedgerEffects = 2,
}Expand description
Event shape for Transactions. Shapes are exclusive and only one of them can be defined in queries.
Variants
Unspecified = 0
Following official proto3 convention, not intended for actual use.
AcsDelta = 1
Transaction shape that is sufficient to maintain an accurate ACS view. The field witness_parties in events are populated as stakeholders, transaction filter will apply accordingly. This translates to create and archive events.
LedgerEffects = 2
Transaction shape that allows maintaining an ACS and also conveys detailed information about all exercises. The field witness_parties in events are populated as cumulative informees, transaction filter will apply accordingly. This translates to create, consuming exercise and non-consuming exercise.
Implementations
Sourceimpl TransactionShape
impl TransactionShape
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of TransactionShape.
Sourcepub fn from_i32(value: i32) -> Option<TransactionShape>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<TransactionShape>
Use the TryFrom<i32> implementation instead
Converts an i32 to a TransactionShape, or None if value is not a valid variant.
Sourceimpl TransactionShape
impl TransactionShape
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<TransactionShape>
pub fn from_str_name(value: &str) -> Option<TransactionShape>
Creates an enum from field names used in the ProtoBuf definition.