pub struct EventQueryServiceClient<T> { /* private fields */ }Expand description
Query events by contract id.
Note that querying by contract key is not (yet) supported, as contract keys are not supported (yet) in multi-synchronizer scenarios.
Implementations
Sourceimpl<T> EventQueryServiceClient<T>where
T: GrpcService<Body>,
<T as GrpcService<Body>>::Error: Into<Box<dyn Error + Sync + Send>>,
<T as GrpcService<Body>>::ResponseBody: Body<Data = Bytes> + Send + 'static,
<<T as GrpcService<Body>>::ResponseBody as Body>::Error: Into<Box<dyn Error + Sync + Send>> + Send,
impl<T> EventQueryServiceClient<T>where
T: GrpcService<Body>,
<T as GrpcService<Body>>::Error: Into<Box<dyn Error + Sync + Send>>,
<T as GrpcService<Body>>::ResponseBody: Body<Data = Bytes> + Send + 'static,
<<T as GrpcService<Body>>::ResponseBody as Body>::Error: Into<Box<dyn Error + Sync + Send>> + Send,
pub fn new(inner: T) -> EventQueryServiceClient<T>
pub fn with_origin(inner: T, origin: Uri) -> EventQueryServiceClient<T>
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> EventQueryServiceClient<InterceptedService<T, F>>where
F: Interceptor,
<T as GrpcService<Body>>::ResponseBody: Default,
T: Service<Request<Body>, Response = Response<<T as GrpcService<Body>>::ResponseBody>>,
<T as Service<Request<Body>>>::Error: Into<Box<dyn Error + Sync + Send>> + Send + Sync,
Sourcepub fn send_compressed(
self,
encoding: CompressionEncoding,
) -> EventQueryServiceClient<T>
pub fn send_compressed( self, encoding: CompressionEncoding, ) -> EventQueryServiceClient<T>
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_compressed(
self,
encoding: CompressionEncoding,
) -> EventQueryServiceClient<T>
pub fn accept_compressed( self, encoding: CompressionEncoding, ) -> EventQueryServiceClient<T>
Enable decompressing responses.
Sourcepub fn max_decoding_message_size(
self,
limit: usize,
) -> EventQueryServiceClient<T>
pub fn max_decoding_message_size( self, limit: usize, ) -> EventQueryServiceClient<T>
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(
self,
limit: usize,
) -> EventQueryServiceClient<T>
pub fn max_encoding_message_size( self, limit: usize, ) -> EventQueryServiceClient<T>
Limits the maximum size of an encoded message.
Default: usize::MAX
Sourcepub async fn get_events_by_contract_id(
&mut self,
request: impl IntoRequest<GetEventsByContractIdRequest>,
) -> Result<Response<GetEventsByContractIdResponse>, Status>
pub async fn get_events_by_contract_id( &mut self, request: impl IntoRequest<GetEventsByContractIdRequest>, ) -> Result<Response<GetEventsByContractIdResponse>, Status>
Get the create and the consuming exercise event for the contract with the provided ID. No events will be returned for contracts that have been pruned because they have already been archived before the latest pruning offset. If the contract cannot be found for the request, or all the contract-events are filtered, a CONTRACT_EVENTS_NOT_FOUND error will be raised.