VersionedNode

Enum VersionedNode 

pub enum VersionedNode {
    V1(Node),
}
Versioned node

Required

Variants



V1(Node)

Start at 1000 so we can add more fields before if necessary When new versions will be added, they will show here

Required

Implementations

Source

impl VersionedNode

pub fn encode(&self, buf: &mut impl BufMut)

Encodes the message to a buffer.

pub fn merge( field: &mut Option<VersionedNode>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>

Decodes an instance of the message from a buffer, and merges it into self.

pub fn encoded_len(&self) -> usize

Returns the encoded length of the message without a length delimiter.