#[repr(i32)]pub enum HashingSchemeVersion {
Unspecified = 0,
V2 = 2,
V3 = 3,
V4 = 4,
}Expand description
[docs-entry-start: HashingSchemeVersion] The hashing scheme version used when building the hash of the PreparedTransaction
Variants
Unspecified = 0
V2 = 2
V3 = 3
V4 = 4
Development-protocol-only hashing scheme for LF development-version prepared transactions. V4 includes exercise external_call_results in the prepared transaction hash.
Implementations
Sourceimpl HashingSchemeVersion
impl HashingSchemeVersion
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of HashingSchemeVersion.
Sourcepub fn from_i32(value: i32) -> Option<HashingSchemeVersion>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<HashingSchemeVersion>
Use the TryFrom<i32> implementation instead
Converts an i32 to a HashingSchemeVersion, or None if value is not a valid variant.
Sourceimpl HashingSchemeVersion
impl HashingSchemeVersion
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<HashingSchemeVersion>
pub fn from_str_name(value: &str) -> Option<HashingSchemeVersion>
Creates an enum from field names used in the ProtoBuf definition.