pub struct CostEstimation {
pub estimation_timestamp: Option<Timestamp>,
pub confirmation_request_traffic_cost_estimation: u64,
pub confirmation_response_traffic_cost_estimation: u64,
pub total_traffic_cost_estimation: u64,
}Expand description
Estimation of the cost of submitting the prepared transaction The estimation is done against the synchronizer chosen during preparation of the transaction (or the one explicitly requested). The cost of re-assigning contracts to another synchronizer when necessary is not included in the estimation.
Fields
estimation_timestamp: Option<Timestamp>Timestamp at which the estimation was made
Required
confirmation_request_traffic_cost_estimation: u64Estimated traffic cost of the confirmation request associated with the transaction
Required
confirmation_response_traffic_cost_estimation: u64Estimated traffic cost of the confirmation response associated with the transaction This field can also be used as an indication of the cost that other potential confirming nodes of the party will incur to approve or reject the transaction
Required
total_traffic_cost_estimation: u64Sum of the fields above
Required