pub struct CostEstimationHints {
pub disabled: bool,
pub expected_signatures: Vec<i32>,
}Expand description
Hints to improve cost estimation precision of a prepared transaction
Fields
disabled: boolDisable cost estimation Default (not set) is false
Optional
expected_signatures: Vec<i32>Details on the keys that will be used to sign the transaction (how many and of which type). Signature size impacts the cost of the transaction. If empty, the signature sizes will be approximated with threshold-many signatures (where threshold is defined in the PartyToParticipant of the external party), using keys in the order they are registered. Empty list is equivalent to not providing this field
Optional: can be empty
Implementations
Sourceimpl CostEstimationHints
impl CostEstimationHints
Sourcepub fn expected_signatures(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<SigningAlgorithmSpec>> ⓘ
pub fn expected_signatures( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<SigningAlgorithmSpec>> ⓘ
Returns an iterator which yields the valid enum values contained in expected_signatures.
Sourcepub fn push_expected_signatures(&mut self, value: SigningAlgorithmSpec)
pub fn push_expected_signatures(&mut self, value: SigningAlgorithmSpec)
Appends the provided enum value to expected_signatures.