pub struct DamlTransaction {
pub version: String,
pub roots: Vec<String>,
pub nodes: Vec<Node>,
pub node_seeds: Vec<NodeSeed>,
}Expand description
Daml Transaction. This represents the effect on the ledger if this transaction is successfully committed.
Fields
version: Stringserialization version, will be >= max(nodes version)
Required
roots: Vec<String>Root nodes of the transaction
Required: must be non-empty
nodes: Vec<Node>List of nodes in the transaction
Required: must be non-empty
node_seeds: Vec<NodeSeed>Node seeds are values associated with certain nodes used for generating cryptographic salts
Required: must be non-empty