ExecuteSubmissionAndWaitForTransactionRequest

Struct ExecuteSubmissionAndWaitForTransactionRequest 

pub struct ExecuteSubmissionAndWaitForTransactionRequest {
    pub prepared_transaction: Option<PreparedTransaction>,
    pub party_signatures: Option<PartySignatures>,
    pub submission_id: String,
    pub user_id: String,
    pub hashing_scheme_version: i32,
    pub min_ledger_time: Option<MinLedgerTime>,
    pub transaction_format: Option<TransactionFormat>,
    pub deduplication_period: Option<DeduplicationPeriod>,
}

Fields

prepared_transaction: Option<PreparedTransaction>

the prepared transaction Typically this is the value of the prepared_transaction field in PrepareSubmissionResponse obtained from calling prepareSubmission.

Required

party_signatures: Option<PartySignatures>

The party(ies) signatures that authorize the prepared submission to be executed by this node. Each party can provide one or more signatures.. and one or more parties can sign. Note that currently, only single party submissions are supported.

Required

submission_id: String

A unique identifier to distinguish completions for different submissions with the same change ID. Typically a random UUID. Applications are expected to use a different UUID for each retry of a submission with the same change ID. Must be a valid LedgerString (as described in value.proto).

Required

user_id: String

See [PrepareSubmissionRequest.user_id]

Optional

hashing_scheme_version: i32

The hashing scheme version used when building the hash

Required

min_ledger_time: Option<MinLedgerTime>

If set will influence the chosen ledger effective time but will not result in a submission delay so any override should be scheduled to executed within the window allowed by synchronizer.

Optional

transaction_format: Option<TransactionFormat>

If no transaction_format is provided, a default will be used where transaction_shape is set to TRANSACTION_SHAPE_ACS_DELTA, event_format is defined with filters_by_party containing wildcard-template filter for all original act_as and read_as parties and the verbose flag is set. When the transaction_shape TRANSACTION_SHAPE_ACS_DELTA shape is used (explicitly or is defaulted to as explained above), events will only be returned if the submitting party is hosted on this node.

Optional

deduplication_period: Option<DeduplicationPeriod>

Specifies the deduplication period for the change ID (See PrepareSubmissionRequest). If omitted, the participant will assume the configured maximum deduplication time.

Optional

Implementations

Source

impl ExecuteSubmissionAndWaitForTransactionRequest

pub fn hashing_scheme_version(&self) -> HashingSchemeVersion

Returns the enum value of hashing_scheme_version, or the default if the field is set to an invalid enum value.

pub fn set_hashing_scheme_version(&mut self, value: HashingSchemeVersion)

Sets hashing_scheme_version to the provided enum value.