pub struct GetPreferredPackageVersionRequest {
pub parties: Vec<String>,
pub package_name: String,
pub synchronizer_id: String,
pub vetting_valid_at: Option<Timestamp>,
}Fields
parties: Vec<String>The parties whose participants’ vetting state should be considered when resolving the preferred package.
Required: must be non-empty
package_name: StringThe package-name for which the preferred package should be resolved.
Required
synchronizer_id: StringThe synchronizer whose vetting state should be used for resolving this query. If not specified, the vetting states of all synchronizers to which the participant is connected are used.
Optional
vetting_valid_at: Option<Timestamp>The timestamp at which the package vetting validity should be computed on the latest topology snapshot as seen by the participant. If not provided, the participant’s current clock time is used.
Optional