pub struct Metadata {
pub submitter_info: Option<SubmitterInfo>,
pub synchronizer_id: String,
pub mediator_group: u32,
pub transaction_uuid: String,
pub preparation_time: u64,
pub input_contracts: Vec<InputContract>,
pub min_ledger_effective_time: Option<u64>,
pub max_ledger_effective_time: Option<u64>,
pub max_record_time: Option<u64>,
pub global_key_mapping: Vec<GlobalKeyMappingEntry>,
}Expand description
Transaction Metadata Refer to the hashing documentation for information on how it should be hashed.
Fields
submitter_info: Option<SubmitterInfo>Required
synchronizer_id: StringRequired
mediator_group: u32Required
transaction_uuid: StringRequired
preparation_time: u64Required
input_contracts: Vec<InputContract>Not populated if the transaction has no input contracts
Optional: can be empty
min_ledger_effective_time: Option<u64>Optional
max_ledger_effective_time: Option<u64>Optional
max_record_time: Option<u64>Maximum timestamp at which the transaction can be recorded onto the ledger via the synchronizer synchronizer_id.
If submitted after it will be rejected even if otherwise valid, in which case it needs to be prepared and signed again
with a new valid max_record_time.
Set max_record_time in the PreparedTransactionRequest to get this field set accordingly
Optional
global_key_mapping: Vec<GlobalKeyMappingEntry>This fields is deprecated and will always be empty. Keys and associated contracts are already present and signed within the transaction nodes where they’re used
Optional: can be empty
Implementations
Sourceimpl Metadata
impl Metadata
Sourcepub fn min_ledger_effective_time(&self) -> u64
pub fn min_ledger_effective_time(&self) -> u64
Returns the value of min_ledger_effective_time, or the default value if min_ledger_effective_time is unset.
Sourcepub fn max_ledger_effective_time(&self) -> u64
pub fn max_ledger_effective_time(&self) -> u64
Returns the value of max_ledger_effective_time, or the default value if max_ledger_effective_time is unset.
Sourcepub fn max_record_time(&self) -> u64
pub fn max_record_time(&self) -> u64
Returns the value of max_record_time, or the default value if max_record_time is unset.