pub struct PackagePreference {
pub package_reference: Option<PackageReference>,
pub synchronizer_id: String,
}Fields
package_reference: Option<PackageReference>The package reference of the preferred package.
Required
synchronizer_id: StringThe synchronizer for which the preferred package was computed. If the synchronizer_id was specified in the request, then it matches the request synchronizer_id.
Required