pub struct PackageServiceClient<T> { /* private fields */ }Expand description
Allows clients to query the Daml-LF packages that are supported by the server.
Implementations
Sourceimpl<T> PackageServiceClient<T>where
T: GrpcService<Body>,
<T as GrpcService<Body>>::Error: Into<Box<dyn Error + Sync + Send>>,
<T as GrpcService<Body>>::ResponseBody: Body<Data = Bytes> + Send + 'static,
<<T as GrpcService<Body>>::ResponseBody as Body>::Error: Into<Box<dyn Error + Sync + Send>> + Send,
impl<T> PackageServiceClient<T>where
T: GrpcService<Body>,
<T as GrpcService<Body>>::Error: Into<Box<dyn Error + Sync + Send>>,
<T as GrpcService<Body>>::ResponseBody: Body<Data = Bytes> + Send + 'static,
<<T as GrpcService<Body>>::ResponseBody as Body>::Error: Into<Box<dyn Error + Sync + Send>> + Send,
pub fn new(inner: T) -> PackageServiceClient<T>
pub fn with_origin(inner: T, origin: Uri) -> PackageServiceClient<T>
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> PackageServiceClient<InterceptedService<T, F>>where
F: Interceptor,
<T as GrpcService<Body>>::ResponseBody: Default,
T: Service<Request<Body>, Response = Response<<T as GrpcService<Body>>::ResponseBody>>,
<T as Service<Request<Body>>>::Error: Into<Box<dyn Error + Sync + Send>> + Send + Sync,
Sourcepub fn send_compressed(
self,
encoding: CompressionEncoding,
) -> PackageServiceClient<T>
pub fn send_compressed( self, encoding: CompressionEncoding, ) -> PackageServiceClient<T>
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_compressed(
self,
encoding: CompressionEncoding,
) -> PackageServiceClient<T>
pub fn accept_compressed( self, encoding: CompressionEncoding, ) -> PackageServiceClient<T>
Enable decompressing responses.
Sourcepub fn max_decoding_message_size(self, limit: usize) -> PackageServiceClient<T>
pub fn max_decoding_message_size(self, limit: usize) -> PackageServiceClient<T>
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(self, limit: usize) -> PackageServiceClient<T>
pub fn max_encoding_message_size(self, limit: usize) -> PackageServiceClient<T>
Limits the maximum size of an encoded message.
Default: usize::MAX
Sourcepub async fn list_packages(
&mut self,
request: impl IntoRequest<ListPackagesRequest>,
) -> Result<Response<ListPackagesResponse>, Status>
pub async fn list_packages( &mut self, request: impl IntoRequest<ListPackagesRequest>, ) -> Result<Response<ListPackagesResponse>, Status>
Returns the identifiers of all supported packages.
Sourcepub async fn get_package(
&mut self,
request: impl IntoRequest<GetPackageRequest>,
) -> Result<Response<GetPackageResponse>, Status>
pub async fn get_package( &mut self, request: impl IntoRequest<GetPackageRequest>, ) -> Result<Response<GetPackageResponse>, Status>
Returns the contents of a single package.
Sourcepub async fn get_package_status(
&mut self,
request: impl IntoRequest<GetPackageStatusRequest>,
) -> Result<Response<GetPackageStatusResponse>, Status>
pub async fn get_package_status( &mut self, request: impl IntoRequest<GetPackageStatusRequest>, ) -> Result<Response<GetPackageStatusResponse>, Status>
Returns the status of a single package.
Sourcepub async fn list_vetted_packages(
&mut self,
request: impl IntoRequest<ListVettedPackagesRequest>,
) -> Result<Response<ListVettedPackagesResponse>, Status>
pub async fn list_vetted_packages( &mut self, request: impl IntoRequest<ListVettedPackagesRequest>, ) -> Result<Response<ListVettedPackagesResponse>, Status>
Lists which participant node vetted what packages on which synchronizer. Can be called by any authenticated user.