pub struct ActiveContract {
pub created_event: Option<CreatedEvent>,
pub synchronizer_id: String,
pub reassignment_counter: u64,
}Fields
created_event: Option<CreatedEvent>The event as it appeared in the context of its last update (i.e. daml transaction or reassignment). In particular, the last offset, node_id pair is preserved. The last update is the most recent update created or assigned this contract on synchronizer_id synchronizer. The offset of the CreatedEvent might point to an already pruned update, therefore it cannot necessarily be used for lookups.
Required
synchronizer_id: StringA valid synchronizer id
Required
reassignment_counter: u64Each corresponding assigned and unassigned event has the same reassignment_counter. This strictly increases with each unassign command for the same contract. Creation of the contract corresponds to reassignment_counter equals zero. This field will be the reassignment_counter of the latest observable activation event on this synchronizer, which is before the active_at_offset.
Required