pub struct AssignCommand {
pub reassignment_id: String,
pub source: String,
pub target: String,
}Expand description
Assign a contract
Fields
reassignment_id: StringThe ID from the unassigned event to be completed by this assignment.
Must be a valid LedgerString (as described in value.proto).
Required
source: StringThe ID of the source synchronizer Must be a valid synchronizer id
Required
target: StringThe ID of the target synchronizer Must be a valid synchronizer id
Required