pub struct AssignedEvent {
pub source: String,
pub target: String,
pub reassignment_id: String,
pub submitter: String,
pub reassignment_counter: u64,
pub created_event: Option<CreatedEvent>,
}Expand description
Records that a contract has been assigned, and it can be used on the target synchronizer.
Fields
source: StringThe ID of the source synchronizer. Must be a valid synchronizer id.
Required
target: StringThe ID of the target synchronizer. Must be a valid synchronizer id.
Required
reassignment_id: StringThe ID from the unassigned event.
For correlation capabilities.
Must be a valid LedgerString (as described in value.proto).
Required
submitter: StringParty on whose behalf the assign command was executed.
Empty if the assignment happened offline via the repair service.
Must be a valid PartyIdString (as described in value.proto).
Optional
reassignment_counter: u64Each corresponding assigned and unassigned event has the same reassignment_counter. This strictly increases with each unassign command for the same contract. Creation of the contract corresponds to reassignment_counter equals zero.
Required
created_event: Option<CreatedEvent>The offset of this event refers to the offset of the assignment, while the node_id is the index of within the batch.
Required