Commands

Struct Commands 

pub struct Commands {
Show 15 fields pub workflow_id: String, pub user_id: String, pub command_id: String, pub commands: Vec<Command>, pub min_ledger_time_abs: Option<Timestamp>, pub min_ledger_time_rel: Option<Duration>, pub act_as: Vec<String>, pub read_as: Vec<String>, pub submission_id: String, pub disclosed_contracts: Vec<DisclosedContract>, pub synchronizer_id: String, pub package_id_selection_preference: Vec<String>, pub prefetch_contract_keys: Vec<PrefetchContractKey>, pub taps_max_passes: Option<u32>, pub deduplication_period: Option<DeduplicationPeriod>,
}
A composite command that groups multiple commands together.

Fields

workflow_id: String

Identifier of the on-ledger workflow that this command is a part of. Must be a valid LedgerString (as described in value.proto).

Optional

user_id: String

Uniquely identifies the participant user that issued the command. Must be a valid UserIdString (as described in value.proto). Required unless authentication is used with a user token. In that case, the token’s user-id will be used for the request’s user_id.

Optional

command_id: String

Uniquely identifies the command. The triple (user_id, act_as, command_id) constitutes the change ID for the intended ledger change, where act_as is interpreted as a set of party names. The change ID can be used for matching the intended ledger changes with all their completions. Must be a valid LedgerString (as described in value.proto).

Required

commands: Vec<Command>

Individual elements of this atomic command. Must be non-empty.

Required: must be non-empty

min_ledger_time_abs: Option<Timestamp>

Lower bound for the ledger time assigned to the resulting transaction. Note: The ledger time of a transaction is assigned as part of command interpretation. Use this property if you expect that command interpretation will take a considerate amount of time, such that by the time the resulting transaction is sequenced, its assigned ledger time is not valid anymore. Must not be set at the same time as min_ledger_time_rel.

Optional

min_ledger_time_rel: Option<Duration>

Same as min_ledger_time_abs, but specified as a duration, starting from the time the command is received by the server. Must not be set at the same time as min_ledger_time_abs.

Optional

act_as: Vec<String>

Set of parties on whose behalf the command should be executed. If ledger API authorization is enabled, then the authorization metadata must authorize the sender of the request to act on behalf of each of the given parties. Each element must be a valid PartyIdString (as described in value.proto).

Required: must be non-empty

read_as: Vec<String>

Set of parties on whose behalf (in addition to all parties listed in act_as) contracts can be retrieved. This affects Daml operations such as fetch, fetchByKey, lookupByKey, exercise, and exerciseByKey. Note: A participant node of a Daml network can host multiple parties. Each contract present on the participant node is only visible to a subset of these parties. A command can only use contracts that are visible to at least one of the parties in act_as or read_as. This visibility check is independent from the Daml authorization rules for fetch operations. If ledger API authorization is enabled, then the authorization metadata must authorize the sender of the request to read contract data on behalf of each of the given parties.

Optional: can be empty

submission_id: String

A unique identifier to distinguish completions for different submissions with the same change ID. Typically a random UUID. Applications are expected to use a different UUID for each retry of a submission with the same change ID. Must be a valid LedgerString (as described in value.proto).

If omitted, the participant or the committer may set a value of their choice.

Optional

disclosed_contracts: Vec<DisclosedContract>

Additional contracts used to resolve contract & contract key lookups.

Optional: can be empty

synchronizer_id: String

Must be a valid synchronizer id

Optional

package_id_selection_preference: Vec<String>

The package-id selection preference of the client for resolving package names and interface instances in command submission and interpretation

Optional: can be empty

prefetch_contract_keys: Vec<PrefetchContractKey>

Fetches the contract keys into the caches to speed up the command processing. Each entry specifies a key and a limit on how many contracts to prefetch for that key. The limit does not count disclosed contracts, and should reflect the number of additional contracts expected to be resolved during interpretation of the commands. If a key appears multiple times, the last entry’s limit wins.

Optional: can be empty

taps_max_passes: Option<u32>

The maximum number of passes for the Topology-Aware Package Selection (TAPS). Higher values can increase the chance of successful package selection for routing of interpreted transactions. If unset, this defaults to the value defined in the participant configuration. The provided value must not exceed the limit specified in the participant configuration.

Optional

deduplication_period: Option<DeduplicationPeriod>

Specifies the deduplication period for the change ID. If omitted, the participant will assume the configured maximum deduplication time.

Optional

Implementations

Source

impl Commands

pub fn taps_max_passes(&self) -> u32

Returns the value of taps_max_passes, or the default value if taps_max_passes is unset.