pub struct CompletionStreamRequest {
pub user_id: String,
pub parties: Vec<String>,
pub begin_exclusive: i64,
}Fields
user_id: StringOnly completions of commands submitted with the same user_id will be visible in the stream.
Must be a valid UserIdString (as described in value.proto).
Required unless authentication is used with a user token. In that case, the token’s user-id will be used for the request’s user_id.
Optional
parties: Vec<String>Non-empty list of parties whose data should be included.
The stream shows only completions of commands for which at least one of the act_as parties is in the given set of parties.
Must be a valid PartyIdString (as described in value.proto).
Required: must be non-empty
begin_exclusive: i64This optional field indicates the minimum offset for completions. This can be used to resume an earlier completion stream. If not set the ledger uses the ledger begin offset instead. If specified, it must be a valid absolute offset (positive integer) or zero (ledger begin offset). If the ledger has been pruned, this parameter must be specified and greater than the pruning offset.
Optional