pub struct CreateAndExerciseCommand {
pub template_id: Option<Identifier>,
pub create_arguments: Option<Record>,
pub choice: String,
pub choice_argument: Option<Value>,
}Expand description
Create a contract and exercise a choice on it in the same transaction.
Fields
template_id: Option<Identifier>The template of the contract the client wants to create. Both package-name and package-id reference identifier formats for the template-id are supported. Note: The package-id reference identifier format is deprecated. We plan to end support for this format in version 3.4.
Required
create_arguments: Option<Record>The arguments required for creating a contract from this template.
Required
choice: StringThe name of the choice the client wants to exercise.
Must be a valid NameString (as described in value.proto).
Required
choice_argument: Option<Value>The argument for this choice.
Required