pub struct CreateCommand {
pub template_id: Option<Identifier>,
pub create_arguments: Option<Record>,
}Expand description
Create a new contract instance based on a template.
Fields
template_id: Option<Identifier>The template of contract the client wants to create. Both package-name and package-id reference identifier formats for the template-id are supported. Note: The package-id reference identifier format is deprecated. We plan to end support for this format in version 3.4.
Required
create_arguments: Option<Record>The arguments required for creating a contract from this template.
Required