pub struct DisclosedContract {
pub template_id: Option<Identifier>,
pub contract_id: String,
pub created_event_blob: Vec<u8>,
pub synchronizer_id: String,
}Expand description
An additional contract that is used to resolve contract & contract key lookups.
Fields
template_id: Option<Identifier>The template id of the contract. The identifier uses the package-id reference format.
If provided, used to validate the template id of the contract serialized in the created_event_blob.
Optional
contract_id: StringThe contract id
If provided, used to validate the contract id of the contract serialized in the created_event_blob.
Optional
created_event_blob: Vec<u8>Opaque byte string containing the complete payload required by the Daml engine to reconstruct a contract not known to the receiving participant.
Required: must be non-empty
synchronizer_id: StringThe ID of the synchronizer where the contract is currently assigned
Optional