pub struct ExerciseByKeyCommand {
pub template_id: Option<Identifier>,
pub contract_key: Option<Value>,
pub choice: String,
pub choice_argument: Option<Value>,
}Expand description
Exercise a choice on an existing contract specified by its key.
Fields
template_id: Option<Identifier>The template of contract the client wants to exercise. Both package-name and package-id reference identifier formats for the template-id are supported. Note: The package-id reference identifier format is deprecated. We plan to end support for this format in version 3.4.
Required
contract_key: Option<Value>The key of the contract the client wants to exercise upon.
Required
choice: StringThe name of the choice the client wants to exercise.
Must be a valid NameString (as described in value.proto)
Required
choice_argument: Option<Value>The argument for this choice.
Required