pub struct ExerciseCommand {
pub template_id: Option<Identifier>,
pub contract_id: String,
pub choice: String,
pub choice_argument: Option<Value>,
}Expand description
Exercise a choice on an existing contract.
Fields
template_id: Option<Identifier>The template or interface of the contract the client wants to exercise. Both package-name and package-id reference identifier formats for the template-id are supported. Note: The package-id reference identifier format is deprecated. We plan to end support for this format in version 3.4. To exercise a choice on an interface, specify the interface identifier in the template_id field.
Required
contract_id: StringThe ID of the contract the client wants to exercise upon.
Must be a valid LedgerString (as described in value.proto).
Required
choice: StringThe name of the choice the client wants to exercise.
Must be a valid NameString (as described in value.proto)
Required
choice_argument: Option<Value>The argument for this choice.
Required