pub struct FeaturesDescriptor {
pub experimental: Option<ExperimentalFeatures>,
pub user_management: Option<UserManagementFeature>,
pub party_management: Option<PartyManagementFeature>,
pub offset_checkpoint: Option<OffsetCheckpointFeature>,
pub package_feature: Option<PackageFeature>,
}Fields
experimental: Option<ExperimentalFeatures>Features under development or features that are used for ledger implementation testing purposes only.
Daml applications SHOULD not depend on these in production.
Required
user_management: Option<UserManagementFeature>If set, then the Ledger API server supports user management. It is recommended that clients query this field to gracefully adjust their behavior for ledgers that do not support user management.
Required
party_management: Option<PartyManagementFeature>If set, then the Ledger API server supports party management configurability. It is recommended that clients query this field to gracefully adjust their behavior to maximum party page size.
Required
offset_checkpoint: Option<OffsetCheckpointFeature>It contains the timeouts related to the periodic offset checkpoint emission
Required
package_feature: Option<PackageFeature>If set, then the Ledger API server supports package listing configurability. It is recommended that clients query this field to gracefully adjust their behavior to maximum package listing page size.
Required