pub struct GetConnectedSynchronizersRequest {
pub party: String,
pub participant_id: String,
pub identity_provider_id: String,
}Fields
party: StringThe party of interest
Must be a valid PartyIdString (as described in value.proto).
If empty, all synchronizers this node is connected to will be returned
Optional
participant_id: StringThe id of a participant whose mapping of a party to connected synchronizers is requested. Must be a valid participant-id retrieved through a prior call to getParticipantId. Defaults to the participant id of the host participant.
Optional
identity_provider_id: StringThe ID of the identity provider configured by Identity Provider Config
If not set, it’s assumed the user is managed by the default identity provider.
Optional