pub struct GetContractRequest {
pub contract_id: String,
pub querying_parties: Vec<String>,
}Fields
contract_id: StringThe ID of the contract.
Must be a valid LedgerString (as described in value.proto).
Required
querying_parties: Vec<String>The list of querying parties The stakeholders of the referenced contract must have an intersection with any of these parties to return the result. If no querying_parties specified, all possible contracts could be returned.
Optional: can be empty