pub struct GetPackageResponse {
pub hash_function: i32,
pub archive_payload: Vec<u8>,
pub hash: String,
}Fields
hash_function: i32The hash function we use to calculate the hash.
Required
archive_payload: Vec<u8>Contains a daml_lf ArchivePayload. See further details in daml_lf.proto.
Required: must be non-empty
hash: StringThe hash of the archive payload, can also used as a package_id.
Must be a valid PackageIdString (as described in value.proto).
Required
Implementations
Sourceimpl GetPackageResponse
impl GetPackageResponse
Sourcepub fn hash_function(&self) -> HashFunction
pub fn hash_function(&self) -> HashFunction
Returns the enum value of hash_function, or the default if the field is set to an invalid enum value.
Sourcepub fn set_hash_function(&mut self, value: HashFunction)
pub fn set_hash_function(&mut self, value: HashFunction)
Sets hash_function to the provided enum value.