pub struct GetUpdatesRequest {
pub begin_exclusive: i64,
pub end_inclusive: Option<i64>,
pub update_format: Option<UpdateFormat>,
pub descending_order: bool,
}Expand description
Exclusive lower bound offset of the requested ledger section (non-negative integer). The response will only contain transactions whose offset is strictly greater than this. If set to zero, the lower bound is set to the beginning of the ledger. If the participant has been pruned, this parameter must be greater or equal than the pruning offset.
Fields
begin_exclusive: i64Required
end_inclusive: Option<i64>Inclusive higher bound offset of the requested ledger section. If specified the response will only contain transactions whose offset is less than or equal to this. If not specified,
- the descending_order must not be selected,
- the stream will not terminate.
Optional
update_format: Option<UpdateFormat>The update format for this request
Required
descending_order: boolIf set, the stream will populate the elements in descending order.
Optional
Implementations
Sourceimpl GetUpdatesRequest
impl GetUpdatesRequest
Sourcepub fn end_inclusive(&self) -> i64
pub fn end_inclusive(&self) -> i64
Returns the value of end_inclusive, or the default value if end_inclusive is unset.