pub struct IncompleteUnassigned {
pub created_event: Option<CreatedEvent>,
pub unassigned_event: Option<UnassignedEvent>,
}Fields
created_event: Option<CreatedEvent>The event as it appeared in the context of its last activation update (i.e. daml transaction or reassignment). In particular, the last activation offset, node_id pair is preserved. The last activation update is the most recent update created or assigned this contract on synchronizer_id synchronizer before the unassigned_event. The offset of the CreatedEvent might point to an already pruned update, therefore it cannot necessarily be used for lookups.
Required
unassigned_event: Option<UnassignedEvent>Required