pub struct InterfaceFilter {
pub interface_id: Option<Identifier>,
pub include_interface_view: bool,
pub include_created_event_blob: bool,
}Expand description
This filter matches contracts that implement a specific interface.
Fields
interface_id: Option<Identifier>The interface that a matching contract must implement.
The interface_id needs to be valid: corresponding interface should be defined in
one of the available packages at the time of the query.
Both package-name and package-id reference formats for the identifier are supported.
Note: The package-id reference identifier format is deprecated. We plan to end support for this format in version 3.4.
Required
include_interface_view: boolWhether to include the interface view on the contract in the returned CreatedEvent.
Use this to access contract data in a uniform manner in your API client.
Optional
include_created_event_blob: boolWhether to include a created_event_blob in the returned CreatedEvent.
Use this to access the contract create event payload in your API client
for submitting it as a disclosed contract with future commands.
Optional