InterfaceView

Struct InterfaceView 

pub struct InterfaceView {
    pub interface_id: Option<Identifier>,
    pub view_status: Option<Status>,
    pub view_value: Option<Record>,
    pub implementation_package_id: String,
}
View of a create event matched by an interface filter.

Fields

interface_id: Option<Identifier>

The interface implemented by the matched event. The identifier uses the package-id reference format.

Required

view_status: Option<Status>

Whether the view was successfully computed, and if not, the reason for the error. The error is reported using the same rules for error codes and messages as the errors returned for API requests.

Required

view_value: Option<Record>

The value of the interface’s view method on this event. Set if it was requested in the InterfaceFilter and it could be successfully computed.

Optional

implementation_package_id: String

The package defining the interface implementation used to compute the view. Can be different from the package that was used to create the contract itself, as the contract arguments can be upgraded or downgraded using smart-contract upgrading as part of computing the interface view. Populated if the view computation is successful, otherwise empty.

Optional