pub struct OffsetCheckpoint {
pub offset: i64,
pub synchronizer_times: Vec<SynchronizerTime>,
}Expand description
OffsetCheckpoints may be used to:
- detect time out of commands.
- provide an offset which can be used to restart consumption.
Fields
offset: i64The participant’s offset, the details of the offset field are described in community/ledger-api/README.md.
Must be a valid absolute offset (positive integer).
Required
synchronizer_times: Vec<SynchronizerTime>The times associated with each synchronizer at this offset.
Optional: can be empty