pub struct Optional {
pub value: Option<Box<Value>>,
}Expand description
Corresponds to Java’s Optional type, Scala’s Option, and Haskell’s Maybe.
The reason why we need to wrap this in an additional message is that we
need to be able to encode the None case in the Value oneof.
Fields
value: Option<Box<Value>>optional