pub struct Reassignment {
pub update_id: String,
pub command_id: String,
pub workflow_id: String,
pub offset: i64,
pub events: Vec<ReassignmentEvent>,
pub trace_context: Option<TraceContext>,
pub record_time: Option<Timestamp>,
pub synchronizer_id: String,
pub paid_traffic_cost: Option<i64>,
}Expand description
Complete view of an on-ledger reassignment.
Fields
update_id: StringAssigned by the server. Useful for correlating logs.
Must be a valid LedgerString (as described in value.proto).
Required
command_id: StringThe ID of the command which resulted in this reassignment. Missing for everyone except the submitting party on the submitting participant.
Must be a valid LedgerString (as described in value.proto).
Optional
workflow_id: StringThe workflow ID used in reassignment command submission. Only set if the workflow_id for the command was set.
Must be a valid LedgerString (as described in value.proto).
Optional
offset: i64The participant’s offset. The details of this field are described in community/ledger-api/README.md.
Must be a valid absolute offset (positive integer).
Required
events: Vec<ReassignmentEvent>The collection of reassignment events.
Required: must be non-empty
trace_context: Option<TraceContext>Ledger API trace context
The trace context transported in this message corresponds to the trace context supplied by the client application in a HTTP2 header of the original command submission. We typically use a header to transfer this type of information. Here we use message body, because it is used in gRPC streams which do not support per message headers. This field will be populated with the trace context contained in the original submission. If that was not provided, a unique ledger-api-server generated trace context will be used instead.
Optional
record_time: Option<Timestamp>The time at which the reassignment was recorded. The record time refers to the source/target synchronizer for an unassign/assign event respectively.
Required
synchronizer_id: StringA valid synchronizer id. Identifies the synchronizer that synchronized this Reassignment.
Required
paid_traffic_cost: Option<i64>The traffic cost that this participant node paid for the corresponding (un)assignment request.
Not set for transactions that were
- initiated by another participant
- initiated offline via the repair service
- processed before the participant started serving traffic cost on the Ledger API
- returned as part of a query filtering for a non submitting party
Optional
Implementations
Sourceimpl Reassignment
impl Reassignment
Sourcepub fn paid_traffic_cost(&self) -> i64
pub fn paid_traffic_cost(&self) -> i64
Returns the value of paid_traffic_cost, or the default value if paid_traffic_cost is unset.