pub struct Signature {
pub format: i32,
pub signature: Vec<u8>,
pub signed_by: String,
pub signing_algorithm_spec: i32,
}Fields
format: i32Required
signature: Vec<u8>Required: must be non-empty
signed_by: StringThe fingerprint/id of the keypair used to create this signature and needed to verify.
Required
signing_algorithm_spec: i32The signing algorithm specification used to produce this signature
Required
Implementations
Sourceimpl Signature
impl Signature
Sourcepub fn format(&self) -> SignatureFormat
pub fn format(&self) -> SignatureFormat
Returns the enum value of format, or the default if the field is set to an invalid enum value.
Sourcepub fn set_format(&mut self, value: SignatureFormat)
pub fn set_format(&mut self, value: SignatureFormat)
Sets format to the provided enum value.
Sourcepub fn signing_algorithm_spec(&self) -> SigningAlgorithmSpec
pub fn signing_algorithm_spec(&self) -> SigningAlgorithmSpec
Returns the enum value of signing_algorithm_spec, or the default if the field is set to an invalid enum value.
Sourcepub fn set_signing_algorithm_spec(&mut self, value: SigningAlgorithmSpec)
pub fn set_signing_algorithm_spec(&mut self, value: SigningAlgorithmSpec)
Sets signing_algorithm_spec to the provided enum value.