pub struct SigningPublicKey {
pub format: i32,
pub key_data: Vec<u8>,
pub key_spec: i32,
}Fields
format: i32The serialization format of the public key
Required
key_data: Vec<u8>Serialized public key in the format specified above
Required: must be non-empty
key_spec: i32The key specification
Required
Implementations
Sourceimpl SigningPublicKey
impl SigningPublicKey
Sourcepub fn format(&self) -> CryptoKeyFormat
pub fn format(&self) -> CryptoKeyFormat
Returns the enum value of format, or the default if the field is set to an invalid enum value.
Sourcepub fn set_format(&mut self, value: CryptoKeyFormat)
pub fn set_format(&mut self, value: CryptoKeyFormat)
Sets format to the provided enum value.
Sourcepub fn key_spec(&self) -> SigningKeySpec
pub fn key_spec(&self) -> SigningKeySpec
Returns the enum value of key_spec, or the default if the field is set to an invalid enum value.
Sourcepub fn set_key_spec(&mut self, value: SigningKeySpec)
pub fn set_key_spec(&mut self, value: SigningKeySpec)
Sets key_spec to the provided enum value.