pub struct SubmitAndWaitForReassignmentRequest {
pub reassignment_commands: Option<ReassignmentCommands>,
pub event_format: Option<EventFormat>,
}Expand description
This reassignment is executed as a single atomic update.
Fields
reassignment_commands: Option<ReassignmentCommands>The reassignment commands to be submitted.
Required
event_format: Option<EventFormat>If no event_format provided, the result will contain no events. The events in the result, will take shape TRANSACTION_SHAPE_ACS_DELTA.
Optional