pub struct SubmitAndWaitForTransactionRequest {
pub commands: Option<Commands>,
pub transaction_format: Option<TransactionFormat>,
}Expand description
These commands are executed as a single atomic transaction.
Fields
commands: Option<Commands>The commands to be submitted.
Required
transaction_format: Option<TransactionFormat>If no transaction_format is provided, a default will be used where transaction_shape is set to
TRANSACTION_SHAPE_ACS_DELTA, event_format is defined with filters_by_party containing wildcard-template
filter for all original act_as and read_as parties and the verbose flag is set.
Optional