pub struct SubmitAndWaitResponse {
pub update_id: String,
pub completion_offset: i64,
}Fields
update_id: StringThe id of the transaction that resulted from the submitted command.
Must be a valid LedgerString (as described in value.proto).
Required
completion_offset: i64The details of the offset field are described in community/ledger-api/README.md.
Required