pub struct SynchronizerTime {
pub synchronizer_id: String,
pub record_time: Option<Timestamp>,
}Fields
synchronizer_id: StringThe id of the synchronizer.
Required
record_time: Option<Timestamp>All commands with a maximum record time below this value MUST be considered lost if their completion has not arrived before this checkpoint.
Required