pub struct TemplateFilter {
pub template_id: Option<Identifier>,
pub include_created_event_blob: bool,
}Expand description
This filter matches contracts of a specific template.
Fields
template_id: Option<Identifier>A template for which the payload should be included in the response.
The template_id needs to be valid: corresponding template should be defined in
one of the available packages at the time of the query.
Both package-name and package-id reference formats for the identifier are supported.
Note: The package-id reference identifier format is deprecated. We plan to end support for this format in version 3.4.
Required
include_created_event_blob: boolWhether to include a created_event_blob in the returned CreatedEvent.
Use this to access the contract event payload in your API client
for submitting it as a disclosed contract with future commands.
Optional