Transaction

Struct Transaction 

pub struct Transaction {
    pub update_id: String,
    pub command_id: String,
    pub workflow_id: String,
    pub effective_at: Option<Timestamp>,
    pub events: Vec<Event>,
    pub offset: i64,
    pub synchronizer_id: String,
    pub trace_context: Option<TraceContext>,
    pub record_time: Option<Timestamp>,
    pub external_transaction_hash: Option<Vec<u8>>,
    pub paid_traffic_cost: Option<i64>,
    pub transaction_hash: Option<Vec<u8>>,
}
Filtered view of an on-ledger transaction’s create and archive events.

Fields

update_id: String

Assigned by the server. Useful for correlating logs. Must be a valid LedgerString (as described in value.proto).

Required

command_id: String

The ID of the command which resulted in this transaction. Missing for everyone except the submitting party. Must be a valid LedgerString (as described in value.proto).

Optional

workflow_id: String

The workflow ID used in command submission. Must be a valid LedgerString (as described in value.proto).

Optional

effective_at: Option<Timestamp>

Ledger effective time.

Required

events: Vec<Event>

The collection of events. Contains:

  • CreatedEvent or ArchivedEvent in case of ACS_DELTA transaction shape
  • CreatedEvent or ExercisedEvent in case of LEDGER_EFFECTS transaction shape

Required: must be non-empty

offset: i64

The absolute offset. The details of this field are described in community/ledger-api/README.md. It is a valid absolute offset (positive integer).

Required

synchronizer_id: String

A valid synchronizer id. Identifies the synchronizer that synchronized the transaction.

Required

trace_context: Option<TraceContext>

Ledger API trace context

The trace context transported in this message corresponds to the trace context supplied by the client application in a HTTP2 header of the original command submission. We typically use a header to transfer this type of information. Here we use message body, because it is used in gRPC streams which do not support per message headers. This field will be populated with the trace context contained in the original submission. If that was not provided, a unique ledger-api-server generated trace context will be used instead.

Optional

record_time: Option<Timestamp>

The time at which the transaction was recorded. The record time refers to the synchronizer which synchronized the transaction.

Required

external_transaction_hash: Option<Vec<u8>>

Deprecated: please use transaction_hash which has the same value. For transaction externally signed, contains the external transaction hash signed by the external party. Can be used to correlate an external submission with a committed transaction.

Optional: can be empty

paid_traffic_cost: Option<i64>

The traffic cost that this participant node paid for the confirmation request for this transaction.

Not set for transactions that were

  • initiated by another participant
  • initiated offline via the repair service
  • processed before the participant started serving traffic cost on the Ledger API
  • returned as part of a query filtering for a non submitting party

Optional

transaction_hash: Option<Vec<u8>>

The transaction hash signed by the external party for prepared transactions that were submitted using InteractiveSubmissionService.ExecuteSubmission or one of its variants.

Use this to correlate prepared transactions with their execution result on the same participant that executed the transaction.

Not available for:

  • transactions executed on Canton versions prior to 3.6
  • transactions of internal parties submitted using CommandSubmissionService.Submit and its variants

Optional: can be empty

Implementations

Source

impl Transaction

pub fn external_transaction_hash(&self) -> &[u8]

Returns the value of external_transaction_hash, or the default value if external_transaction_hash is unset.

pub fn paid_traffic_cost(&self) -> i64

Returns the value of paid_traffic_cost, or the default value if paid_traffic_cost is unset.

pub fn transaction_hash(&self) -> &[u8]

Returns the value of transaction_hash, or the default value if transaction_hash is unset.