pub struct TransactionFormat {
pub event_format: Option<EventFormat>,
pub transaction_shape: i32,
}Expand description
A format that specifies what events to include in Daml transactions and what data to compute and include for them.
Fields
event_format: Option<EventFormat>Required
transaction_shape: i32What transaction shape to use for interpreting the filters of the event format.
Required
Implementations
Sourceimpl TransactionFormat
impl TransactionFormat
Sourcepub fn transaction_shape(&self) -> TransactionShape
pub fn transaction_shape(&self) -> TransactionShape
Returns the enum value of transaction_shape, or the default if the field is set to an invalid enum value.
Sourcepub fn set_transaction_shape(&mut self, value: TransactionShape)
pub fn set_transaction_shape(&mut self, value: TransactionShape)
Sets transaction_shape to the provided enum value.