pub struct UnassignCommand {
pub contract_id: String,
pub source: String,
pub target: String,
}Expand description
Unassign a contract
Fields
contract_id: StringThe ID of the contract the client wants to unassign.
Must be a valid LedgerString (as described in value.proto).
Required
source: StringThe ID of the source synchronizer Must be a valid synchronizer id
Required
target: StringThe ID of the target synchronizer Must be a valid synchronizer id
Required