pub struct UnassignedEvent {
pub reassignment_id: String,
pub contract_id: String,
pub template_id: Option<Identifier>,
pub source: String,
pub target: String,
pub submitter: String,
pub reassignment_counter: u64,
pub assignment_exclusivity: Option<Timestamp>,
pub witness_parties: Vec<String>,
pub package_name: String,
pub offset: i64,
pub node_id: i32,
}Expand description
Records that a contract has been unassigned, and it becomes unusable on the source synchronizer
Fields
reassignment_id: StringThe ID of the unassignment. This needs to be used as an input for a assign ReassignmentCommand.
Must be a valid LedgerString (as described in value.proto).
Required
contract_id: StringThe ID of the reassigned contract.
Must be a valid LedgerString (as described in value.proto).
Required
template_id: Option<Identifier>The template of the reassigned contract. The identifier uses the package-id reference format.
Required
source: StringThe ID of the source synchronizer Must be a valid synchronizer id
Required
target: StringThe ID of the target synchronizer Must be a valid synchronizer id
Required
submitter: StringParty on whose behalf the unassign command was executed.
Empty if the unassignment happened offline via the repair service.
Must be a valid PartyIdString (as described in value.proto).
Optional
reassignment_counter: u64Each corresponding assigned and unassigned event has the same reassignment_counter. This strictly increases with each unassign command for the same contract. Creation of the contract corresponds to reassignment_counter equals zero.
Required
assignment_exclusivity: Option<Timestamp>Assignment exclusivity Before this time (measured on the target synchronizer), only the submitter of the unassignment can initiate the assignment Defined for reassigning participants.
Optional
witness_parties: Vec<String>The parties that are notified of this event.
Required: must be non-empty
package_name: StringThe package name of the contract.
Required
offset: i64The offset of origin. Offsets are managed by the participant nodes. Reassignments can thus NOT be assumed to have the same offsets on different participant nodes. Must be a valid absolute offset (positive integer)
Required
node_id: i32The position of this event in the originating reassignment. Node IDs are not necessarily equal across participants, as these may see different projections/parts of reassignments. Must be valid node ID (non-negative integer)
Required