pub struct UpdateFormat {
pub include_transactions: Option<TransactionFormat>,
pub include_reassignments: Option<EventFormat>,
pub include_topology_events: Option<TopologyFormat>,
}Expand description
A format specifying what updates to include and how to render them.
Fields
include_transactions: Option<TransactionFormat>Include Daml transactions in streams. If unset, no transactions are emitted in the stream.
Optional
include_reassignments: Option<EventFormat>Include (un)assignments in the stream. The events in the result take the shape TRANSACTION_SHAPE_ACS_DELTA. If unset, no (un)assignments are emitted in the stream.
Optional
include_topology_events: Option<TopologyFormat>Include topology events in streams. If unset no topology events are emitted in the stream.
Optional