pub struct UserManagementFeature {
pub supported: bool,
pub max_rights_per_user: i32,
pub max_users_page_size: i32,
}Fields
supported: boolWhether the Ledger API server provides the user management service.
Required
max_rights_per_user: i32The maximum number of rights that can be assigned to a single user. Servers MUST support at least 100 rights per user. A value of 0 means that the server enforces no rights per user limit.
Required
max_users_page_size: i32The maximum number of users the server can return in a single response (page). Servers MUST support at least a 100 users per page. A value of 0 means that the server enforces no page size limit.
Required