UpdateServiceClient

Struct UpdateServiceClient 

pub struct UpdateServiceClient<T> { /* private fields */ }
Allows clients to read updates (transactions, (un)assignments, topology events) from the ledger.

GetUpdates provides a comprehensive stream of updates/changes which happened on the virtual shared ledger. These streams are indexed with ledger offsets, which are strictly increasing. The virtual shared ledger consist of changes happening on multiple synchronizers which are connected to the serving participant. Each update belongs to one synchronizer, this is provided in the result (the synchronizer_id field in Transaction for transactions, the source field in UnassignedEvent and the target field in AssignedEvent). Consumers can rely on strong causal guarantees on the virtual shared ledger for a single synchronizer: updates which have greater offsets are happened after than updates with smaller offsets for the same synchronizer. Across different synchronizers this is not guaranteed.

Implementations

Source

impl UpdateServiceClient<Channel>

pub async fn connect<D>(dst: D) -> Result<UpdateServiceClient<Channel>, Error>
where D: TryInto<Endpoint>, <D as TryInto<Endpoint>>::Error: Into<Box<dyn Error + Sync + Send>>,

Attempt to create a new client by connecting to a given endpoint.

Source

impl<T> UpdateServiceClient<T>
where T: GrpcService<Body>, <T as GrpcService<Body>>::Error: Into<Box<dyn Error + Sync + Send>>, <T as GrpcService<Body>>::ResponseBody: Body<Data = Bytes> + Send + 'static, <<T as GrpcService<Body>>::ResponseBody as Body>::Error: Into<Box<dyn Error + Sync + Send>> + Send,

pub fn new(inner: T) -> UpdateServiceClient<T>

pub fn with_origin(inner: T, origin: Uri) -> UpdateServiceClient<T>

pub fn with_interceptor<F>( inner: T, interceptor: F, ) -> UpdateServiceClient<InterceptedService<T, F>>

pub fn send_compressed( self, encoding: CompressionEncoding, ) -> UpdateServiceClient<T>

Compress requests with the given encoding.

This requires the server to support it otherwise it might respond with an error.

pub fn accept_compressed( self, encoding: CompressionEncoding, ) -> UpdateServiceClient<T>

Enable decompressing responses.

pub fn max_decoding_message_size(self, limit: usize) -> UpdateServiceClient<T>

Limits the maximum size of a decoded message.

Default: 4MB

pub fn max_encoding_message_size(self, limit: usize) -> UpdateServiceClient<T>

Limits the maximum size of an encoded message.

Default: usize::MAX

pub async fn get_updates( &mut self, request: impl IntoRequest<GetUpdatesRequest>, ) -> Result<Response<Streaming<GetUpdatesResponse>>, Status>

Read the ledger’s filtered update stream for the specified contents and filters. It returns the event types in accordance with the stream contents selected. Also the selection criteria for individual events depends on the transaction shape chosen.

  • ACS delta: a requesting party must be a stakeholder of an event for it to be included.
  • ledger effects: a requesting party must be a witness of an event for it to be included.
pub async fn get_update_by_offset( &mut self, request: impl IntoRequest<GetUpdateByOffsetRequest>, ) -> Result<Response<GetUpdateResponse>, Status>

Lookup an update by its offset. If there is no update with this offset, or all the events are filtered, an UPDATE_NOT_FOUND error will be raised.

pub async fn get_update_by_id( &mut self, request: impl IntoRequest<GetUpdateByIdRequest>, ) -> Result<Response<GetUpdateResponse>, Status>

Lookup an update by its ID. If there is no update with this ID, or all the events are filtered, an UPDATE_NOT_FOUND error will be raised.

pub async fn get_update_by_hash( &mut self, request: impl IntoRequest<GetUpdateByHashRequest>, ) -> Result<Response<GetUpdateResponse>, Status>

Look up an update by its transaction hash. This is only available for updates received after upgrading to Canton version 3.6. If there is no update with this transaction hash, or all the events are filtered, or the update was populated before upgrading to Canton version 3.6, an UPDATE_NOT_FOUND error will be raised.

pub async fn get_updates_page( &mut self, request: impl IntoRequest<GetUpdatesPageRequest>, ) -> Result<Response<GetUpdatesPageResponse>, Status>

Read a page of ledger’s filtered updates. It returns the event types in accordance with the specified contents and filters. Additionally, the selection criteria for individual events depends on the transaction shape chosen.

  • ACS delta: an event is included only if the requesting party is a stakeholder.
  • ledger effects: an event is included if the requesting party is a witness.