Sum

Enum Sum 

pub enum Sum {
Show 16 variants Unit(()), Bool(bool), Int64(i64), Date(i32), Timestamp(i64), Numeric(String), Party(String), Text(String), ContractId(String), Optional(Box<Optional>), List(List), TextMap(TextMap), GenMap(GenMap), Record(Record), Variant(Box<Variant>), Enum(Enum),
}

Variants



Unit(())

This value is used for example for choices that don’t take any arguments.



Bool(bool)

True or false.



Int64(i64)



Date(i32)

Days since the unix epoch. Can go backwards. Limited from 0001-01-01 to 9999-12-31, also to be compatible with https://www.ietf.org/rfc/rfc3339.txt



Timestamp(i64)

Microseconds since the UNIX epoch. Can go backwards. Fixed since the vast majority of values will be greater than 2^28, since currently the number of microseconds since the epoch is greater than that. Range: 0001-01-01T00:00:00Z to 9999-12-31T23:59:59.999999Z, so that we can convert to/from https://www.ietf.org/rfc/rfc3339.txt



Numeric(String)

A Numeric, that is a decimal value with precision 38 (at most 38 significant digits) and a scale between 0 and 37 (significant digits on the right of the decimal point). The field has to match the regex

.. code-block:: none

[+-]?\d{1,38}(.\d{0,37})?

and should be representable by a Numeric without loss of precision.



Party(String)

An agent operating on the ledger. Must be a valid PartyIdString.



Text(String)

A string.



ContractId(String)

Identifier of an on-ledger contract. Commands which reference an unknown or already archived contract ID will fail. Must be a valid LedgerString.



Optional(Box<Optional>)

The Optional type, None or Some



List(List)

Represents a homogeneous list of values.



TextMap(TextMap)

The TextMap type



GenMap(GenMap)

The GenMap type



Record(Record)



Variant(Box<Variant>)



Enum(Enum)

The Enum type

Implementations

Source

impl Sum

pub fn encode(&self, buf: &mut impl BufMut)

Encodes the message to a buffer.

pub fn merge( field: &mut Option<Sum>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>

Decodes an instance of the message from a buffer, and merges it into self.

pub fn encoded_len(&self) -> usize

Returns the encoded length of the message without a length delimiter.