#[non_exhaustive]pub enum TransactionShape {
AcsDelta,
LedgerEffects,
}Expand description
The shape of transactions in an update stream — which events are returned
and who has to see them (see the Ledger API’s TransactionShape).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AcsDelta
Created and archived events describing the net change to the active contract set; a requesting party must be a stakeholder of an event.
LedgerEffects
Create and (non-)consuming exercise events as executed; a requesting
party must be a witness of an event. The default, matching
CantonClient::updates.