pub struct CommandInspectionServiceClient<T> { /* private fields */ }Expand description
Status: experimental interface, will change before it is deemed production ready
The inspection service provides methods for the ledger administrator to look under the hood of a running system. In V2 Ledger API this service is not available.
Implementations
Sourceimpl<T> CommandInspectionServiceClient<T>where
T: GrpcService<Body>,
<T as GrpcService<Body>>::Error: Into<Box<dyn Error + Sync + Send>>,
<T as GrpcService<Body>>::ResponseBody: Body<Data = Bytes> + Send + 'static,
<<T as GrpcService<Body>>::ResponseBody as Body>::Error: Into<Box<dyn Error + Sync + Send>> + Send,
impl<T> CommandInspectionServiceClient<T>where
T: GrpcService<Body>,
<T as GrpcService<Body>>::Error: Into<Box<dyn Error + Sync + Send>>,
<T as GrpcService<Body>>::ResponseBody: Body<Data = Bytes> + Send + 'static,
<<T as GrpcService<Body>>::ResponseBody as Body>::Error: Into<Box<dyn Error + Sync + Send>> + Send,
pub fn new(inner: T) -> CommandInspectionServiceClient<T>
pub fn with_origin(inner: T, origin: Uri) -> CommandInspectionServiceClient<T>
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> CommandInspectionServiceClient<InterceptedService<T, F>>where
F: Interceptor,
<T as GrpcService<Body>>::ResponseBody: Default,
T: Service<Request<Body>, Response = Response<<T as GrpcService<Body>>::ResponseBody>>,
<T as Service<Request<Body>>>::Error: Into<Box<dyn Error + Sync + Send>> + Send + Sync,
Sourcepub fn send_compressed(
self,
encoding: CompressionEncoding,
) -> CommandInspectionServiceClient<T>
pub fn send_compressed( self, encoding: CompressionEncoding, ) -> CommandInspectionServiceClient<T>
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_compressed(
self,
encoding: CompressionEncoding,
) -> CommandInspectionServiceClient<T>
pub fn accept_compressed( self, encoding: CompressionEncoding, ) -> CommandInspectionServiceClient<T>
Enable decompressing responses.
Sourcepub fn max_decoding_message_size(
self,
limit: usize,
) -> CommandInspectionServiceClient<T>
pub fn max_decoding_message_size( self, limit: usize, ) -> CommandInspectionServiceClient<T>
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(
self,
limit: usize,
) -> CommandInspectionServiceClient<T>
pub fn max_encoding_message_size( self, limit: usize, ) -> CommandInspectionServiceClient<T>
Limits the maximum size of an encoded message.
Default: usize::MAX
Sourcepub async fn get_command_status(
&mut self,
request: impl IntoRequest<GetCommandStatusRequest>,
) -> Result<Response<GetCommandStatusResponse>, Status>
pub async fn get_command_status( &mut self, request: impl IntoRequest<GetCommandStatusRequest>, ) -> Result<Response<GetCommandStatusResponse>, Status>
Inquire about the status of a command. This service is used for debugging only. The command status is only tracked in memory and is not persisted. The service can be used to understand the failure status and the structure of a command. Requires admin privileges The service is alpha without backward compatibility guarantees.