ListKnownPartiesRequest

Struct ListKnownPartiesRequest 

pub struct ListKnownPartiesRequest {
    pub page_token: String,
    pub page_size: i32,
    pub identity_provider_id: String,
    pub filter_party: String,
}
Required authorization: HasRight(ParticipantAdmin) OR IsAuthenticatedIdentityProviderAdmin(identity_provider_id)

Fields

page_token: String

Pagination token to determine the specific page to fetch. Using the token guarantees that parties on a subsequent page are all lexically greater than the last party on a previous page. Server does not store intermediate results between calls chained by a series of page tokens. As a consequence, if new parties are being added and a page is requested twice using the same token, more parties can be returned on the second call. Leave empty to fetch the first page.

Optional

page_size: i32

Maximum number of results to be returned by the server. The server will return no more than that many results, but it might return fewer. If the page_size is 0, the server will decide the number of results to be returned. If the page_size exceeds the maximum supported by the server, an error will be returned. To obtain the server’s maximum consult the PartyManagementFeature descriptor available in the VersionService.

Optional

identity_provider_id: String

The id of the Identity Provider whose parties should be retrieved. If not set, assume the party is managed by the default identity provider or party is not hosted by the participant.

Optional

filter_party: String

An optional filter for the party name, searching for all party names known to this node starting with the given prefix. This can either be just a string or extend up to the full identifier.

Optional