User

Struct User 

pub struct User {
    pub id: String,
    pub primary_party: String,
    pub is_deactivated: bool,
    pub metadata: Option<ObjectMeta>,
    pub identity_provider_id: String,
    pub primary_party_authentication: bool,
}
Users are used to dynamically manage the rights given to Daml applications. They are stored and managed per participant node.

Fields

id: String

The user identifier, which must be a non-empty string of at most 128 characters that are either alphanumeric ASCII characters or one of the symbols “@^$.!`-#+’~_|:()”.

Required

primary_party: String

The primary party as which this user reads and acts by default on the ledger provided it has the corresponding CanReadAs(primary_party) or CanActAs(primary_party) rights. Ledger API clients SHOULD set this field to a non-empty value for all users to enable the users to act on the ledger using their own Daml party. Users for participant administrators MAY have an associated primary party. Modifiable

Optional

is_deactivated: bool

When set, then the user is denied all access to the Ledger API. Otherwise, the user has access to the Ledger API as per the user’s rights. Modifiable

Optional

metadata: Option<ObjectMeta>

The metadata of this user. Note that the metadata.resource_version tracks changes to the properties described by the User message and not the user’s rights. Modifiable

Optional

identity_provider_id: String

The ID of the identity provider configured by Identity Provider Config If not set, assume the user is managed by the default identity provider.

Optional

primary_party_authentication: bool

If set to true, the user may authenticate against the Ledger API by signing a Party JWT using the primary party’s signing key. Modifiable

Optional