pub struct CommandServiceClient<T> { /* private fields */ }Expand description
Command Service is able to correlate submitted commands with completion data, identify timeouts, and return contextual information with each tracking result. This supports the implementation of stateless clients.
Note that submitted commands generally produce completion events as well, even in case a command gets rejected. For example, the participant SHOULD produce a completion event for a rejection of a duplicate command.
Implementations
Sourceimpl<T> CommandServiceClient<T>where
T: GrpcService<Body>,
<T as GrpcService<Body>>::Error: Into<Box<dyn Error + Sync + Send>>,
<T as GrpcService<Body>>::ResponseBody: Body<Data = Bytes> + Send + 'static,
<<T as GrpcService<Body>>::ResponseBody as Body>::Error: Into<Box<dyn Error + Sync + Send>> + Send,
impl<T> CommandServiceClient<T>where
T: GrpcService<Body>,
<T as GrpcService<Body>>::Error: Into<Box<dyn Error + Sync + Send>>,
<T as GrpcService<Body>>::ResponseBody: Body<Data = Bytes> + Send + 'static,
<<T as GrpcService<Body>>::ResponseBody as Body>::Error: Into<Box<dyn Error + Sync + Send>> + Send,
pub fn new(inner: T) -> CommandServiceClient<T>
pub fn with_origin(inner: T, origin: Uri) -> CommandServiceClient<T>
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> CommandServiceClient<InterceptedService<T, F>>where
F: Interceptor,
<T as GrpcService<Body>>::ResponseBody: Default,
T: Service<Request<Body>, Response = Response<<T as GrpcService<Body>>::ResponseBody>>,
<T as Service<Request<Body>>>::Error: Into<Box<dyn Error + Sync + Send>> + Send + Sync,
Sourcepub fn send_compressed(
self,
encoding: CompressionEncoding,
) -> CommandServiceClient<T>
pub fn send_compressed( self, encoding: CompressionEncoding, ) -> CommandServiceClient<T>
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_compressed(
self,
encoding: CompressionEncoding,
) -> CommandServiceClient<T>
pub fn accept_compressed( self, encoding: CompressionEncoding, ) -> CommandServiceClient<T>
Enable decompressing responses.
Sourcepub fn max_decoding_message_size(self, limit: usize) -> CommandServiceClient<T>
pub fn max_decoding_message_size(self, limit: usize) -> CommandServiceClient<T>
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(self, limit: usize) -> CommandServiceClient<T>
pub fn max_encoding_message_size(self, limit: usize) -> CommandServiceClient<T>
Limits the maximum size of an encoded message.
Default: usize::MAX
Sourcepub async fn submit_and_wait(
&mut self,
request: impl IntoRequest<SubmitAndWaitRequest>,
) -> Result<Response<SubmitAndWaitResponse>, Status>
pub async fn submit_and_wait( &mut self, request: impl IntoRequest<SubmitAndWaitRequest>, ) -> Result<Response<SubmitAndWaitResponse>, Status>
Submits a single composite command and waits for its result. Propagates the gRPC error of failed submissions including Daml interpretation errors.
Sourcepub async fn submit_and_wait_for_transaction(
&mut self,
request: impl IntoRequest<SubmitAndWaitForTransactionRequest>,
) -> Result<Response<SubmitAndWaitForTransactionResponse>, Status>
pub async fn submit_and_wait_for_transaction( &mut self, request: impl IntoRequest<SubmitAndWaitForTransactionRequest>, ) -> Result<Response<SubmitAndWaitForTransactionResponse>, Status>
Submits a single composite command, waits for its result, and returns the transaction. Propagates the gRPC error of failed submissions including Daml interpretation errors.
Sourcepub async fn submit_and_wait_for_reassignment(
&mut self,
request: impl IntoRequest<SubmitAndWaitForReassignmentRequest>,
) -> Result<Response<SubmitAndWaitForReassignmentResponse>, Status>
pub async fn submit_and_wait_for_reassignment( &mut self, request: impl IntoRequest<SubmitAndWaitForReassignmentRequest>, ) -> Result<Response<SubmitAndWaitForReassignmentResponse>, Status>
Submits a single composite reassignment command, waits for its result, and returns the reassignment. Propagates the gRPC error of failed submission.