pub struct CommandSubmissionServiceClient<T> { /* private fields */ }Expand description
Allows clients to attempt advancing the ledger’s state by submitting commands. The final states of their submissions are disclosed by the Command Completion Service. The on-ledger effects of their submissions are disclosed by the Update Service.
Commands may fail in 2 distinct manners:
- Failure communicated synchronously in the gRPC error of the submission.
- Failure communicated asynchronously in a Completion, see
completion.proto.
Note that not only successfully submitted commands MAY produce a completion event. For example, the participant MAY choose to produce a completion event for a rejection of a duplicate command.
Clients that do not receive a successful completion about their submission MUST NOT assume that it was successful. Clients SHOULD subscribe to the CompletionStream before starting to submit commands to prevent race conditions.
Implementations
Sourceimpl<T> CommandSubmissionServiceClient<T>where
T: GrpcService<Body>,
<T as GrpcService<Body>>::Error: Into<Box<dyn Error + Sync + Send>>,
<T as GrpcService<Body>>::ResponseBody: Body<Data = Bytes> + Send + 'static,
<<T as GrpcService<Body>>::ResponseBody as Body>::Error: Into<Box<dyn Error + Sync + Send>> + Send,
impl<T> CommandSubmissionServiceClient<T>where
T: GrpcService<Body>,
<T as GrpcService<Body>>::Error: Into<Box<dyn Error + Sync + Send>>,
<T as GrpcService<Body>>::ResponseBody: Body<Data = Bytes> + Send + 'static,
<<T as GrpcService<Body>>::ResponseBody as Body>::Error: Into<Box<dyn Error + Sync + Send>> + Send,
pub fn new(inner: T) -> CommandSubmissionServiceClient<T>
pub fn with_origin(inner: T, origin: Uri) -> CommandSubmissionServiceClient<T>
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> CommandSubmissionServiceClient<InterceptedService<T, F>>where
F: Interceptor,
<T as GrpcService<Body>>::ResponseBody: Default,
T: Service<Request<Body>, Response = Response<<T as GrpcService<Body>>::ResponseBody>>,
<T as Service<Request<Body>>>::Error: Into<Box<dyn Error + Sync + Send>> + Send + Sync,
Sourcepub fn send_compressed(
self,
encoding: CompressionEncoding,
) -> CommandSubmissionServiceClient<T>
pub fn send_compressed( self, encoding: CompressionEncoding, ) -> CommandSubmissionServiceClient<T>
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_compressed(
self,
encoding: CompressionEncoding,
) -> CommandSubmissionServiceClient<T>
pub fn accept_compressed( self, encoding: CompressionEncoding, ) -> CommandSubmissionServiceClient<T>
Enable decompressing responses.
Sourcepub fn max_decoding_message_size(
self,
limit: usize,
) -> CommandSubmissionServiceClient<T>
pub fn max_decoding_message_size( self, limit: usize, ) -> CommandSubmissionServiceClient<T>
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(
self,
limit: usize,
) -> CommandSubmissionServiceClient<T>
pub fn max_encoding_message_size( self, limit: usize, ) -> CommandSubmissionServiceClient<T>
Limits the maximum size of an encoded message.
Default: usize::MAX
Sourcepub async fn submit(
&mut self,
request: impl IntoRequest<SubmitRequest>,
) -> Result<Response<SubmitResponse>, Status>
pub async fn submit( &mut self, request: impl IntoRequest<SubmitRequest>, ) -> Result<Response<SubmitResponse>, Status>
Submit a single composite command.
Sourcepub async fn submit_reassignment(
&mut self,
request: impl IntoRequest<SubmitReassignmentRequest>,
) -> Result<Response<SubmitReassignmentResponse>, Status>
pub async fn submit_reassignment( &mut self, request: impl IntoRequest<SubmitReassignmentRequest>, ) -> Result<Response<SubmitReassignmentResponse>, Status>
Submit a single reassignment.